# @Karlsruher
* is a robot on Twitter ([Link](https://twitter.com/Karlsruher))
* retweets mentions from its followers when they apply some rules
---

## Lifecycle for Developers
Get the source:
```
$ git clone https://github.com/schlind/Karlsruher.git
$ cd Karlsruher
$ ./devreport.sh
```

Create and locally install a version:
```
$ python3 setup.py sdist
$ python3 -m pip install --user dist/karlsruher-VERSION.tar.gz
```

Read [README.setup.md](README.setup.md)!
